outcome_token_from_nautilus_symbol

Function outcome_token_from_nautilus_symbol 

pub fn outcome_token_from_nautilus_symbol(symbol: &str) -> Option<String>
Returns the +<encoding> token form for the side token referenced by a Nautilus outcome symbol, or None if the symbol is not an outcome.